# react-multi

A lightweight, customizable multi-select component for web applications. Easy to integrate, responsive, and supports user interactions with customizable responses.

## 🎉🎉 Features

- Simple setup and usage.
- Customizable styles and behavior.
- Built-in support for user interactions and responses.
- Lightweight with minimal dependencies.
- Easily customizable via props.
- Typescript support
- [Small bundle size](https://bundlephobia.com/result?p=react-multi)

## Example

![Example](https://res.cloudinary.com/saimun/image/upload/c_scale,w_450/v1730702819/gifmaker_me_2_xaynlw.gif)

## 1. Installation

`npm install react-multi`

`yarn add react-multi`

`pnpm add react-multi`

## 2. Live Demo

[React-beautiful-modal](https://react-multi.vercel.app/doc/usage)

## 3. Simple usage

```javascript
import React, { useState } from "react";
import { Modal } from "react-beautiful-modals";

const App = () => {
  const [open, setOpen] = useState(false);

  return (
    <Modal open={open} onClose={() => setOpen(false)}>
      <h1>You content here</h1>
    </Modal>
  );
};

export default App;
```

## 3.1 With component usage

```javascript
import React, { useState } from "react";
import {
  Modal,
  ModalCancelButton,
  ModalDescription,
  ModalFooter,
  ModalHeader,
  ModalSuccessButton,
  ModalTitle,
} from "react-beautiful-modals";

const App = () => {
  const [open, setOpen] = useState(false);

  return (
    <Modal open={open} onClose={() => setOpen(false)}>
      <ModalHeader>
        <ModalTitle>This is modal title</ModalTitle>
      </ModalHeader>
      <ModalDescription>This is modal Description</ModalDescription>
      <ModalFooter>
        <ModalCancelButton onClose={() => setOpen(false)}>
          Cancel
        </ModalCancelButton>
        <ModalSuccessButton>Continue</ModalSuccessButton>
      </ModalFooter>
    </Modal>
  );
};

export default App;
```

## Read Documentation

[React-beautiful-modal](https://react-beautiful-modal.vercel.app/doc/installation)

# Props

| Prop                       | Type                                    | Default | Description                                                               |
| -------------------------- | --------------------------------------- | ------- | ------------------------------------------------------------------------- |
| **`open`**                 | `boolean`                               |         | Controls the visibility of the modal or modal content.                    |
| **`onClose`**              | `() => void`                            |         | Callback function to handle closing of the modal.                         |
| **`children`**             | `React.ReactNode`                       |         | Content to be displayed inside the component.                             |
| **`size`**                 | `"sm","md","lg"`                        | `"sm"`  | Size of the modal.                                                        |
| **`animationType`**        | `"slide-up","slide-down","fade","zoom"` | "zoom"  | Type of animation used for the modal.                                     |
| **`width`**                | `number`                                | "25vw"  | Custom width for the modal.                                               |
| **`disableBackdropClick`** | `boolean`                               | `false` | Disables closing the modal when clicking on the backdrop.                 |
| **`customModalOverly`**    | `string`                                |         | Custom class name to apply additional styles or override existing styles. |
| **`customModalContent`**   | `string`                                |         | Custom class name to apply additional styles or override existing styles. |



This documentation helps developers understand the props they can use, along with their types and defaults, including how to apply custom styles through `customClass`.
